@@ -29,6 +29,7 @@ DEFAULT_METADATA = from_conf("DEFAULT_METADATA", "local")
 DEFAULT_MONITOR = from_conf("DEFAULT_MONITOR", "nullSidecarMonitor")
 DEFAULT_PACKAGE_SUFFIXES = from_conf("DEFAULT_PACKAGE_SUFFIXES", ".py,.R,.RDS")
 DEFAULT_AWS_CLIENT_PROVIDER = from_conf("DEFAULT_AWS_CLIENT_PROVIDER", "boto3")
+DEFAULT_SECRETS_BACKEND_TYPE = from_conf("DEFAULT_SECRETS_BACKEND_TYPE")
 
 
 ###
@@ -129,6 +130,9 @@ DATATOOLS_LOCALROOT = from_conf(
     else None,
 )
 
+# Secrets Backend - AWS Secrets Manager configuration
+AWS_SECRETS_MANAGER_DEFAULT_REGION = from_conf("AWS_SECRETS_MANAGER_DEFAULT_REGION")
+
 # The root directory to save artifact pulls in, when using S3 or Azure
 ARTIFACT_LOCALROOT = from_conf("ARTIFACT_LOCALROOT", os.getcwd())
 
@@ -257,6 +261,9 @@ KUBERNETES_CONTAINER_REGISTRY = from_conf(
     "KUBERNETES_CONTAINER_REGISTRY", DEFAULT_CONTAINER_REGISTRY
 )
 
+ARGO_WORKFLOWS_KUBERNETES_SECRETS = from_conf("ARGO_WORKFLOWS_KUBERNETES_SECRETS", "")
+ARGO_WORKFLOWS_ENV_VARS_TO_SKIP = from_conf("ARGO_WORKFLOWS_ENV_VARS_TO_SKIP", "")
+
 ##
 # Airflow Configuration
 ##
@@ -266,6 +273,10 @@ AIRFLOW_KUBERNETES_STARTUP_TIMEOUT_SECONDS = from_conf(
 )
 # This configuration sets `kubernetes_conn_id` in airflow's KubernetesPodOperator.
 AIRFLOW_KUBERNETES_CONN_ID = from_conf("AIRFLOW_KUBERNETES_CONN_ID")
+AIRFLOW_KUBERNETES_KUBECONFIG_FILE = from_conf("AIRFLOW_KUBERNETES_KUBECONFIG_FILE")
+AIRFLOW_KUBERNETES_KUBECONFIG_CONTEXT = from_conf(
+    "AIRFLOW_KUBERNETES_KUBECONFIG_CONTEXT"
+)
 
 
 ###
