@@ -24,6 +24,10 @@ from metaflow.metaflow_config import (
     DATASTORE_SYSROOT_GS,
     CARD_AZUREROOT,
     CARD_GSROOT,
+    DEFAULT_SECRETS_BACKEND_TYPE,
+    AWS_SECRETS_MANAGER_DEFAULT_REGION,
+    ARGO_WORKFLOWS_KUBERNETES_SECRETS,
+    ARGO_WORKFLOWS_ENV_VARS_TO_SKIP,
 )
 from metaflow.mflog import BASH_SAVE_LOGS, bash_capture_logs, export_mflog_env_vars
 from metaflow.parameters import deploy_time_eval
@@ -119,7 +123,7 @@ class ArgoWorkflows(object):
 
         self.parameters = self._process_parameters()
         self._workflow_template = self._compile()
-        self._cron = self._cron()
+        self._cron = self._get_cron()
 
     def __str__(self):
         return str(self._workflow_template)
@@ -172,17 +176,22 @@ class ArgoWorkflows(object):
         except Exception as e:
             raise ArgoWorkflowsException(str(e))
 
-    def _cron(self):
+    def _get_cron(self):
         schedule = self.flow._flow_decorators.get("schedule")
         if schedule:
             # Remove the field "Year" if it exists
-            return " ".join(schedule.schedule.split()[:5])
+            schedule = schedule[0]
+            return " ".join(schedule.schedule.split()[:5]), schedule.timezone
         return None
 
     def schedule(self):
         try:
+            if self._cron is None:
+                cron, timezone = None, None
+            else:
+                cron, timezone = self._cron
             ArgoClient(namespace=KUBERNETES_NAMESPACE).schedule_workflow_template(
-                self.name, self._cron
+                self.name, cron, timezone
             )
         except Exception as e:
             raise ArgoWorkflowsSchedulingException(str(e))
@@ -220,7 +229,7 @@ class ArgoWorkflows(object):
 
     def _process_parameters(self):
         parameters = []
-        has_schedule = self._cron() is not None
+        has_schedule = self._get_cron() is not None
         seen = set()
         for var, param in self.flow._get_parameters():
             # Throw an exception if the parameter is specified twice.
@@ -800,6 +809,12 @@ class ArgoWorkflows(object):
             # support Metaflow sandboxes
             env["METAFLOW_INIT_SCRIPT"] = KUBERNETES_SANDBOX_INIT_SCRIPT
 
+            # secrets stuff
+            env["METAFLOW_DEFAULT_SECRETS_BACKEND_TYPE"] = DEFAULT_SECRETS_BACKEND_TYPE
+            env[
+                "METAFLOW_AWS_SECRETS_MANAGER_DEFAULT_REGION"
+            ] = AWS_SECRETS_MANAGER_DEFAULT_REGION
+
             # Azure stuff
             env[
                 "METAFLOW_AZURE_STORAGE_BLOB_SERVICE_ENDPOINT"
@@ -842,8 +857,13 @@ class ArgoWorkflows(object):
                 )
 
             # It makes no sense to set env vars to None (shows up as "None" string)
-            env_without_none_values = {k: v for k, v in env.items() if v is not None}
-            del env
+            # Also we skip some env vars (e.g. in case we want to pull them from KUBERNETES_SECRETS)
+            env_vars_to_skip = set(ARGO_WORKFLOWS_ENV_VARS_TO_SKIP.split(","))
+            env = {
+                k: v
+                for k, v in env.items()
+                if v is not None and k not in env_vars_to_skip
+            }
 
             # Create a ContainerTemplate for this node. Ideally, we would have
             # liked to inline this ContainerTemplate and avoid scanning the workflow
@@ -896,7 +916,7 @@ class ArgoWorkflows(object):
                             command=cmds,
                             env=[
                                 kubernetes_sdk.V1EnvVar(name=k, value=str(v))
-                                for k, v in env_without_none_values.items()
+                                for k, v in env.items()
                             ]
                             # Add environment variables for book-keeping.
                             # https://argoproj.github.io/argo-workflows/fields/#fields_155
@@ -914,6 +934,7 @@ class ArgoWorkflows(object):
                                     "METAFLOW_KUBERNETES_POD_NAME": "metadata.name",
                                     "METAFLOW_KUBERNETES_POD_ID": "metadata.uid",
                                     "METAFLOW_KUBERNETES_SERVICE_ACCOUNT_NAME": "spec.serviceAccountName",
+                                    "METAFLOW_KUBERNETES_NODE_IP": "status.hostIP",
                                 }.items()
                             ],
                             image=resources["image"],
@@ -946,6 +967,7 @@ class ArgoWorkflows(object):
                                     else resources.get("secrets")
                                 )
                                 + KUBERNETES_SECRETS.split(",")
+                                + ARGO_WORKFLOWS_KUBERNETES_SECRETS.split(",")
                                 if k
                             ],
                             # Assign a volume point to pass state to the next task.
